#!/usr/bin/env node
'use strict';

var fs = require('fs');
var path = require('path');

var scripts = require('react-app-scripts');

var scriptName = process.argv[2].trim();
var dirName = process.cwd();
var rcFilePath = path.join(dirName, '.scriptsrc');

// global config
var gConfig = JSON.parse(fs.readFileSync(rcFilePath, 'utf8'));

function getConfig(script) {
  var config = gConfig[script];
  config.entry = gConfig.entry;
  config.appSrc = gConfig.appSrc;
  config.rootPath = dirName;
  config.schema = Object.assign(config.schema || {}, gConfig.schema);
  if (gConfig.reactHot) {
    config.reactHot = Object.assign(config.reactHot || {}, gConfig.reactHot);
  }
  if (gConfig.sass) {
    config.sass = Object.assign(config.sass || {}, gConfig.sass);
  }
  return config;
}

switch (scriptName) {
  case 'serve':
    {
      var config = getConfig('serve');
      scripts.serve(config);
      break;
    }

  case 'build':
    {
      var _config = getConfig('build');
      scripts.build(_config);
      break;
    }

  case 'test':
    {
      var _config2 = gConfig.test;
      scripts.test(_config2);
      break;
    }

  default:
    {
      console.log(scriptName + ' command not found.');
    }
}